@@ -31,42 +31,40 @@
 
 #include <stdlib.h>
 
-#include <qpen.h>
-#include <qbitmap.h>
-#include <qpainter.h>
-
-#include <kmainwindow.h>
+#include <QtGui/QPen>
+#include <QtGui/QBitmap>
+#include <QtGui/QPainter>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPixmap>
+#include <QtCore/QAbstractEventDispatcher>
+#include <kxmlguiwindow.h>
 #include <klocale.h>
 #include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <krun.h>
+#include <ktoolinvocation.h>
+#include <kshell.h>
 
 static const char description[] =
    I18N_NOOP("KDE Free disk space utility");
 
-static const char version[] = "0.2";
-
-static KCmdLineOptions options[] =
-{
-   KCmdLineLastOption
-};
+static const char version[] = "0.3";
 
 /*****************************************************************************/
 
 KwikDisk::KwikDisk()
-   : KSystemTray()
-   , m_readingDF(FALSE)
-   , m_dirty(TRUE)
-   , m_menuVisible(FALSE)
-   , m_inside(FALSE)
+   : KSystemTrayIcon()
+   , m_readingDF(false)
+   , m_dirty(true)
+   , m_inside(false)
    , m_optionDialog(0)
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
-   setPixmap(KSystemTray::loadIcon("kdf"));
+   setIcon(KSystemTrayIcon::loadIcon("kdf"));
    show();
 
    connect( &m_diskList, SIGNAL(readDFDone()), this, SLOT(updateDFDone()) );
@@ -77,50 +75,33 @@ KwikDisk::KwikDisk()
 
    loadSettings();
    updateDF();
-}
-
-void KwikDisk::aboutToHide()
-{
-   kdDebug() << k_funcinfo << endl;
-   if( !m_inside )
-      m_menuVisible = FALSE;
+   connect( this, SIGNAL( activated(QSystemTrayIcon::ActivationReason)),
+            SLOT(slotActivated(QSystemTrayIcon::ActivationReason) ));
 }
 
 void KwikDisk::enterEvent(QEvent *)
 {
-   kdDebug() << k_funcinfo << endl;
-   m_inside = TRUE;
+   kDebug() ;
+   m_inside = true;
 }
 
 void KwikDisk::leaveEvent(QEvent *)
 {
-   kdDebug() << k_funcinfo << endl;
-   m_inside = FALSE;
+   kDebug() ;
+   m_inside = false;
 }
 
-void KwikDisk::mousePressEvent(QMouseEvent *me)
+void KwikDisk::slotActivated(QSystemTrayIcon::ActivationReason)
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    if( m_dirty )
       updateDF();
-
-   if( m_menuVisible )
-   {
-      contextMenu()->hide();
-      m_menuVisible = FALSE;
-      me->ignore();
-      return;
-   }
-
-   contextMenuAboutToShow(contextMenu());
-   contextMenu()->popup( me->globalPos() );
-   m_menuVisible = TRUE;
 }
 
 void KwikDisk::loadSettings()
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    m_options.updateConfiguration();
    setUpdateFrequency( m_options.updateFrequency() );
@@ -128,13 +109,13 @@ void KwikDisk::loadSettings()
 
 void KwikDisk::setUpdateFrequency(int frequency)
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    //
    // Kill current timer and restart it if the frequency is
    // larger than zero.
    //
-   killTimers();
+   QAbstractEventDispatcher::instance()->unregisterTimers(this);
    if( frequency > 0 )
    {
       startTimer(frequency * 1000);
@@ -148,13 +129,13 @@ void KwikDisk::setUpdateFrequency(int frequency)
  */
 void KwikDisk::timerEvent(QTimerEvent *)
 {
-   kdDebug() << k_funcinfo << endl;
-   m_dirty = TRUE;
+   kDebug() ;
+   m_dirty = true;
 }
 
 void KwikDisk::updateDF()
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    m_readingDF = true;
    m_diskList.readFSTAB();
@@ -163,21 +144,21 @@ void KwikDisk::updateDF()
 
 void KwikDisk::updateDFDone()
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
-   m_readingDF = FALSE;
-   m_dirty     = FALSE;
+   m_readingDF = false;
+   m_dirty     = false;
 
    contextMenu()->clear();
-   contextMenu()->insertTitle(KSystemTray::loadIcon("kdf"), i18n("KwikDisk"));
+   contextMenu()->setTitle(i18n("KwikDisk"));
 
    int itemNo = 0;
    for( DiskEntry *disk = m_diskList.first(); disk != 0; disk = m_diskList.next() )
    {
       // FIXME: tool tips are unused atm
-      QString toolTipText = i18n("%1 (%2) %3 on %4")
-         .arg( disk->mounted() ? i18n("Unmount") : i18n("Mount"))
-         .arg(disk->fsType()).arg(disk->deviceName()).arg(disk->mountPoint());
+      QString toolTipText = i18n("%1 (%2) %3 on %4",
+           disk->mounted() ? i18nc("Unmount the storage device", "Unmount") : i18nc("Mount the storage device", "Mount"),
+          disk->fsType(), disk->deviceName(), disk->mountPoint());
 
       QString entryName = disk->mountPoint();
       if( disk->mounted() )
@@ -188,9 +169,9 @@ void KwikDisk::updateDFDone()
       contextMenu()->setItemParameter(id, itemNo);
       itemNo++;
 
-      QPixmap *pix = new QPixmap(KSystemTray::loadIcon(disk->iconName()));
+      QPixmap pix(KSystemTrayIcon::loadIcon(disk->iconName()).pixmap());
 
-      if( getuid() !=0 && disk->mountOptions().find("user",0, false) == -1 )
+      if( getuid() !=0 && !disk->mountOptions().contains("user",Qt::CaseInsensitive) == -1 )
       {
          //
          // Special root icon, normal user cant mount.
@@ -199,53 +180,48 @@ void KwikDisk::updateDFDone()
          // Careful here: If the mask has not been defined we can
          // not use QPixmap::mask() because it returns 0 => segfault
          //
-         if( pix->mask() != 0 )
+         if( !pix.mask().isNull() )
          {
-            QBitmap *bm = new QBitmap(*(pix->mask()));
+            QBitmap *bm = new QBitmap((pix.mask()));
             if( bm != 0 )
             {
                QPainter qp( bm );
-               qp.setPen(QPen(white,1));
+               qp.setPen(QPen(Qt::white,1));
                qp.drawRect(0,0,bm->width(),bm->height());
                qp.end();
-               pix->setMask(*bm);
+               pix.setMask(*bm);
             }
-            QPainter qp( pix );
-            qp.setPen(QPen(red,1));
-            qp.drawRect(0,0,pix->width(),pix->height());
+            QPainter qp( &pix );
+            qp.setPen(QPen(Qt::red,1));
+            qp.drawRect(0,0,pix.width(),pix.height());
             qp.end();
          }
          contextMenu()->disconnectItem(id,disk,SLOT(toggleMount()));
          toolTipText = i18n("You must login as root to mount this disk");
       }
 
-      contextMenu()->changeItem(*pix,entryName,id);
+      contextMenu()->changeItem(id,pix,entryName);
    }
 
-   contextMenu()->insertSeparator();
+   contextMenu()->addSeparator();
 
    contextMenu()->insertItem(
-      KSystemTray::loadIcon("kdf"),
+      KSystemTrayIcon::loadIcon("kdf"),
       i18n("&Start KDiskFree"), this, SLOT(startKDF()),0);
 
    contextMenu()->insertItem(
-      KSystemTray::loadIcon("configure"),
+      KSystemTrayIcon::loadIcon("configure"),
       i18n("&Configure KwikDisk..."), this, SLOT(changeSettings()),0);
 
    contextMenu()->insertItem(
-      KSystemTray::loadIcon("help"),
-      KStdGuiItem::help().text(), this, SLOT(invokeHelp()),0);
+      KSystemTrayIcon::loadIcon("help-contents"),
+      KStandardGuiItem::help().text(), this, SLOT(invokeHelp()),0);
 
-   contextMenu()->insertSeparator();
-
-   contextMenu()->insertItem(
-      KSystemTray::loadIcon("exit"),
-      KStdGuiItem::quit().text(), this, SIGNAL(quitSelected()) );
 }
 
 void KwikDisk::toggleMount(int item)
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    DiskEntry *disk = m_diskList.at(item);
    if( disk == 0 )
@@ -256,38 +232,38 @@ void KwikDisk::toggleMount(int item)
    int val = disk->toggleMount();
    if( val != 0 )
    {
-      KMessageBox::error(this, disk->lastSysError());
+      KMessageBox::error(0, disk->lastSysError());
    }
    else if( (m_options.openFileManager() == true) && (disk->mounted() == true ) )
    {
-      kdDebug() << "opening filemanager" << endl;
+      kDebug() << "opening filemanager" ;
       if( m_options.fileManager().isEmpty() == false )
       {
          QString cmd = m_options.fileManager();
-         int pos = cmd.find("%m");
+         int pos = cmd.indexOf("%m");
          if( pos > 0 )
          {
-            cmd = cmd.replace( pos, 2, KProcess::quote(disk->mountPoint()) ) + " &";
+            cmd = cmd.replace( pos, 2, KShell::quoteArg(disk->mountPoint()) ) + " &";
          }
          else
          {
-            cmd += " " + KProcess::quote(disk->mountPoint()) +" &";
+            cmd += ' ' + KShell::quoteArg(disk->mountPoint()) +" &";
          }
          system( QFile::encodeName(cmd) );
       }
    }
-   m_dirty = TRUE;
+   m_dirty = true;
 }
 
 void KwikDisk::criticallyFull(DiskEntry *disk)
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    if( m_options.popupIfFull() == true )
    {
-      QString msg = i18n("Device [%1] on [%2] is getting critically full!")
-                    .arg(disk->deviceName()).arg(disk->mountPoint());
-      KMessageBox::sorry( this, msg, i18n("Warning"));
+      QString msg = i18n("Device [%1] on [%2] is critically full.",
+                     disk->deviceName(), disk->mountPoint());
+      KMessageBox::sorry( 0, msg, i18nc("Device is getting critically full", "Warning"));
    }
 }
 
@@ -295,7 +271,7 @@ void KwikDisk::changeSettings()
 {
    if( m_optionDialog == 0 )
    {
-      m_optionDialog = new COptionDialog(this, "options", FALSE);
+      m_optionDialog = new COptionDialog(0);
       if( !m_optionDialog ) return;
       connect(m_optionDialog, SIGNAL(valueChanged()),
                         this, SLOT(loadSettings()));
@@ -305,31 +281,34 @@ void KwikDisk::changeSettings()
 
 void KwikDisk::startKDF()
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
-   KRun::runCommand("kdf");
+   KRun::runCommand("kdf",NULL);
 }
 
 void KwikDisk::invokeHelp()
 {
-   kapp->invokeHelp("", "kdf");
+   KToolInvocation::invokeHelp("", "kdf");
 }
 
 /*****************************************************************************/
 
 int main(int argc, char **argv)
 {
-   KLocale::setMainCatalogue( "kdf" );
+   KLocale::setMainCatalog( "kdf" );
 
-   KAboutData about("kwikdisk", I18N_NOOP("KwikDisk"), version, description,
-                  KAboutData::License_GPL, "(C) 2004 Stanislav Karchebny",
-                  0, 0, "Stanislav.Karchebny@kdemail.net");
-   about.addAuthor( "Michael Kropfberger", I18N_NOOP("Original author"),
+   KAboutData about("kwikdisk", 0, ki18n("KwikDisk"), version, ki18n(description),
+                  KAboutData::License_GPL, ki18n("(C) 2004 Stanislav Karchebny"),
+                  KLocalizedString(), "http://utils.kde.org/projects/kdf",
+                  "Stanislav.Karchebny@kdemail.net");
+   about.addAuthor( ki18n("Michael Kropfberger"), ki18n("Original author"),
                     "michael.kropfberger@gmx.net" );
-   about.addAuthor( "Espen Sand", I18N_NOOP("KDE 2 changes"), "" );
-   about.addAuthor( "Stanislav Karchebny", I18N_NOOP("KDE 3 changes"),
+   about.addAuthor( ki18n("Espen Sand"), ki18n("KDE 2 changes"));
+   about.addAuthor( ki18n("Stanislav Karchebny"), ki18n("KDE 3 changes"),
                     "Stanislav.Karchebny@kdemail.net" );
    KCmdLineArgs::init(argc, argv, &about);
+
+   KCmdLineOptions options;
    KCmdLineArgs::addCmdLineOptions( options );
    KApplication app;
    KwikDisk *mainWin = 0;
